#!/usr/bin/env python

##*****************************************************************************
##
## File         createNode.py
##
## Description  WireTap SDK sample python program to create a library node or
##              any other generic node.
##
## Copyright 2016 Autodesk, Inc.  All rights reserved.
## Use of this software is subject to the terms of the Autodesk license
## agreement provided at the time of installation or download, or which
## otherwise accompanies this software in either electronic or hard copy form.
##
##*****************************************************************************

import sys
import getopt
import string

from libwiretapPythonClientAPI import WireTapClient
from libwiretapPythonClientAPI import WireTapServerHandle
from libwiretapPythonClientAPI import WireTapNodeHandle

## Please see the Wiretap Developer's Guide for an explanation of the 
## Wiretap IFFFS server nodes hierarchy..

##*****************************************************************************
class WireTapException( Exception ):
  pass

##*****************************************************************************
def main(argv):

  # check the command line options for correctness
  try:
    opts, args = getopt.getopt(argv, "h:n:t:d:")
  except getopt.GetoptError:
    print "Usage:\n" \
          "-h <hostname>\n" \
          "-n <parent node id>\n"\
          "-t <node type>\n"\
          "-d <node name>"
    sys.exit(2)

  # default host name and node ID
  hostName = "localhost"
  nodeId = ""
  nodeType = "LIBRARY"
  nodeName = "New Node"

  # parse command line option to set specified host name
  # and node ID
  for opt, arg in opts:
    if opt == '-h':
      hostName = arg
    elif opt == '-n':
      nodeId = arg
    elif opt == '-t':
      nodeType = arg
    elif opt == '-d':
      nodeName = arg

  # Initialize the Wiretap Client API.
  #
  wireTapClient = WireTapClient()
  if not wireTapClient.init():
    raise WireTapException( "Unable to initialize WireTap client API." )

  createNode( hostName, nodeId, nodeName, nodeType )


##*****************************************************************************
def createNode( hostName, nodeId, nodeName, nodeType ):

  # Instantiate a server handle
  #
  server = WireTapServerHandle( hostName )

  # Instantiate the clip node handle for the given server and node ID.
  #
  parent = WireTapNodeHandle( server, nodeId )

  # Create a new node of type 'nodeType'. Each Wiretap server defines a set of
  # node types (specified as string constants).
  #
  newNode = WireTapNodeHandle()
  if not parent.createNode( nodeName,
                            nodeType,
                            newNode ):
    raise WireTapException( 'Unable to create node type %s: %s.' % ( nodeType, parent.lastError() ) )

  print( "New node created '%s'" % newNode.getNodeId().id() );

##*****************************************************************************
if __name__ == '__main__':
  main(sys.argv[1:])
