#!/usr/bin/env python

import getopt
from sys import exit,argv,exc_info
from libwiretapPythonClientAPI import *

def getAllTranslationGroups( server ):
  
  # First, obtain the total number of groups
  numGroups = WireTapInt()
  if not server.getNumTranslationGroups( numGroups ): 
    raise Exception( server.lastError()  )

  # Using the numGroups obtained above to retrieve all the groups
  for i in range(numGroups):
    group = WireTapServerHandle.TranslationGroup
    if not server.getTranslationGroup( i, group ): 
      raise Exception( server.lastError() )

    # Print out the group's information
    print "Group Name: %s" % group.getGroupName()
    print "      OS:   %s" % group.getOSType()
    numHosts = group.getNumHosts()
    for j in range(numHosts):
      print"      host: %s" % group.getHost(j)
    print

def getAllHostTranslations( server ):
  
  # First, obtain the total number of host translations
  numHostTranslations = WireTapInt()
  if not server.getNumHostTranslations( numHostTranslations ):
    raise Exception( server.lastError() )

  # Using the numHostTranslations obtained above to retrieve all the host translations
  for i in range(numHostTranslations):
    hostTranslation = WireTapServerHandle.HostTranslation
    if not server.getHostTranslation( i, hostTranslation ): 
      raise Exception( server.lastError() )

    # Print out the host translation's information
    print "Source Host Name: %s " % hostTranslation.getSourceHost()
    print "Source Host Path: %s " % hostTranslation.getSourcePath()
    print "Destination Host Name: %s " % ( 
          hostTranslation.getDestinationHost())
    print "Destination Host Path: %s " % (
           hostTranslation.getDestinationPath())
    print
    
def getAllOsTypeTranslations( server ):
    
  # First, obtain the total number of type translations
  numOsTypeTranslations = WireTapInt()
  if not server.getNumOsTypeTranslations( numOsTypeTranslations ): 
    raise Exception( server.lastError() )

  # Use the numOsTypeTranslations obtained above to retrieve all the
  # OS type translations
  for i in range( numOsTypeTranslations):
    osTypeTranslation = WireTapServerHandle.OsTypeTranslation
    if not server.getOsTypeTranslation( i, osTypeTranslation ): 
      raise Exception( server.lastError() )

    #Print out the host translation's information
    print "Source Host Type: %s " % osTypeTranslation.getSourceType()
    print "Source Host Path: %s " % osTypeTranslation.getSourcePath()
    print "Destination Host Type: %s " % (
           osTypeTranslation.getDestinationType())
    print "Destination Host Path: %s " % (
           osTypeTranslation.getDestinationPath())
    print

def main(argv):

  hostName = str( WireTapOS.getHostName() )
  
  # Initialize the Wiretap Client API.
  #
  wiretapClient = WireTapClient()
  if not wiretapClient.init():
    raise Exception( "Unable to initialize WireTap client API" )

  try:
    # Instantiate a server handle
    #
    server = WireTapServerHandle( hostName )

    try:
      getAllTranslationGroups( server )
      getAllHostTranslations( server )
      getAllOsTypeTranslations( server )
    except:  
      print "Unable to show path translations on '%s': %s. " % (
              hostName, exc_info()[1] )

  finally:
    # Must destroy WireTapServerHandle and WireTapNodeHandle before
    # uninitializing the WireTap Client API.
    #
    server = None


if __name__ == '__main__':
  main(argv[1:])

 
